@@ -4,8 +4,7 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef MAILTRANSPORT_FILTERACTIONJOB_P_H
-#define MAILTRANSPORT_FILTERACTIONJOB_P_H
+#pragma once
 
 #include <mailtransportakonadi_export.h>
 
@@ -163,4 +162,3 @@ private:
 };
 } // namespace Akonadi
 
-#endif // AKONADI_FILTERACTIONJOB_H
