@@ -4,8 +4,7 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef MAILTRANSPORT_RESOURCESENDJOB_P_H
-#define MAILTRANSPORT_RESOURCESENDJOB_P_H
+#pragma once
 
 #include <transportjob.h>
 
@@ -48,4 +47,3 @@ private:
 };
 } // namespace MailTransport
 
-#endif // MAILTRANSPORT_RESOURCESENDJOB_H
