@@ -5,8 +5,7 @@
   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef MAILTRANSPORT_SENTACTIONATTRIBUTE_H
-#define MAILTRANSPORT_SENTACTIONATTRIBUTE_H
+#pragma once
 
 #include <mailtransportakonadi_export.h>
 
@@ -47,7 +46,7 @@ public:
         /**
          * Describes a list of sent actions.
          */
-        typedef QVector<Action> List;
+        using List = QVector<Action>;
 
         /**
          * Creates a new invalid action.
@@ -137,4 +136,3 @@ private:
 }
 Q_DECLARE_TYPEINFO(MailTransport::SentActionAttribute::Action, Q_MOVABLE_TYPE);
 
-#endif
